/* 
 * Copyright (c) 2003 Jean-Yves Lefort <jylefort@brutele.be>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#include "config.h"
#include <gtk/gtk.h>
#include <stdarg.h>
#include "glade-interface.h"
#include "glade-support.h"

/*** functions ***************************************************************/

static void mn_dialog_response (GtkDialog	*dialog,
				int		response,
				gpointer	data);

/*** implementation **********************************************************/

void
mn_notice (const char *format, ...)
{
  va_list args;
  char *message;

  va_start(args, format);
  message = g_strdup_vprintf(format, args);
  va_end(args);

  g_printerr(PACKAGE ": %s\n", message);
}

/*
 * Displays an HIG-compliant modal dialog.
 *
 * Actually, it won't fully comply to the HIG because of
 * http://bugzilla.gnome.org/show_bug.cgi?id=98779.
 */
void
mn_error_dialog (const char *primary,
		 const char *format,
		 ...)
{
  char *secondary = NULL;
  GtkWidget *dialog;
  GtkWidget *image;
  GtkWidget *label;
  GString *message;

  if (format)
    {
      va_list args;
      
      va_start(args, format);
      secondary = g_strdup_vprintf(format, args);
      va_end(args);
    }
  
  dialog = create_dialog();

  image = lookup_widget(dialog, "dialog_image");
  label = lookup_widget(dialog, "dialog_label");

  gtk_image_set_from_stock(GTK_IMAGE(image),
			   GTK_STOCK_DIALOG_ERROR,
			   GTK_ICON_SIZE_DIALOG);

  gtk_window_set_title(GTK_WINDOW(dialog), "");
  gtk_dialog_add_button(GTK_DIALOG(dialog), GTK_STOCK_OK, GTK_RESPONSE_OK);

  message = g_string_new(NULL);

  if (primary)
    g_string_printf(message,
		    "<span weight=\"bold\" size=\"larger\">%s</span>",
		    primary);

  if (secondary)
    {
      if (primary)
	g_string_append(message, "\n\n");

      g_string_append(message, secondary);
    }
  
  g_free(secondary);

  gtk_label_set_markup(GTK_LABEL(label), message->str);
  g_string_free(message, TRUE);
  
  gtk_dialog_run(GTK_DIALOG(dialog));
  gtk_widget_destroy(dialog);
}

/*** utility functions for non-modal dialogs *********************************/

void
mn_dialog_show (GtkDialog *dialog, GtkWidget **ptr)
{
  g_return_if_fail(GTK_IS_DIALOG(dialog));
  g_return_if_fail(ptr != NULL);

  g_signal_connect(G_OBJECT(dialog), "response",
		   G_CALLBACK(mn_dialog_response), NULL);
  g_signal_connect(G_OBJECT(dialog), "destroy",
		   G_CALLBACK(gtk_widget_destroyed), ptr);

  g_object_add_weak_pointer(G_OBJECT(dialog), (void **) ptr);

  gtk_widget_show(GTK_WIDGET(dialog));
}

static void
mn_dialog_response (GtkDialog *dialog, int response, gpointer data)
{
  if (response == GTK_RESPONSE_CLOSE)
    gtk_widget_destroy(GTK_WIDGET(dialog));
}
