/* 
 * Copyright (c) 2003 Jean-Yves Lefort <jylefort@brutele.be>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#include "config.h"
#include <glib.h>
#ifdef HAVE_GNET
#include <gnet.h>
#endif
#include <stdarg.h>
#include "mn-util.h"

/*** implementation **********************************************************/

/*
 * Frees a singly linked list of allocated strings.
 */
void
mn_util_slist_free (GSList *list)
{
  GSList *iter;

  MN_UTIL_SLIST_FOREACH(iter, list)
    g_free(iter->data);

  g_slist_free(list);
}

#ifdef HAVE_GNET
GIOError
mn_util_gnet_io_channel_printf (GIOChannel *channel, const char *format, ...)
{
  va_list args;
  char *message;
  GIOError status;
  int len;
  gsize count;

  g_return_val_if_fail(channel != NULL, G_IO_ERROR_UNKNOWN);
  
  va_start(args, format);
  message = g_strdup_vprintf(format, args);
  va_end(args);

  len = strlen(message);
  status = gnet_io_channel_writen(channel, message, len, &count);
  g_free(message);

  if (status == G_IO_ERROR_NONE && count != len)
    status = G_IO_ERROR_UNKNOWN;

  return status;
}
#endif /* HAVE_GNET */

gboolean
mn_util_is_numeric (const char *str)
{
  int i;

  g_return_val_if_fail(str != NULL, FALSE);

  for (i = 0; str[i]; i++)
    if (! g_ascii_isdigit(str[i]))
      return FALSE;

  return TRUE;
}
